@@ -357,7 +357,7 @@ def _gen_silence(duration):
 def midi_arp(
     notes: List[int] = [],  # arbitrary list of notes to arpeggiate
     root: str = "A3",  # root note of chord
-    chord: str = "minor",  # chord name,
+    chord: str = "min6_9",  # chord name,
     inversions: List[int] = [],  # inversions list
     stack: int = 0,  # stack a chord up or down
     styles: List[str] = ["down"],
